@@ -91,6 +91,10 @@ module Raven
     # We automatically try to set this to a git SHA or Capistrano release.
     attr_accessor :release
 
+    # The sampling factor to apply to events. A value of 0.0 will not send
+    # any events, and a value of 1.0 will send 100% of events.
+    attr_accessor :sample_rate
+
     # Boolean - sanitize values that look like credit card numbers
     attr_accessor :sanitize_credit_cards
 
@@ -126,7 +130,7 @@ module Raven
     # Note that the object passed into the block will be a String (messages) or
     # an exception.
     # e.g. lambda { |exc_or_msg| exc_or_msg.some_attr == false }
-    attr_accessor :should_capture
+    attr_reader :should_capture
 
     # Silences ready message when true.
     attr_accessor :silence_ready
@@ -161,7 +165,8 @@ module Raven
       'ActiveRecord::RecordNotFound',
       'CGI::Session::CookieStore::TamperedWithCookie',
       'Mongoid::Errors::DocumentNotFound',
-      'Sinatra::NotFound'
+      'Sinatra::NotFound',
+      'ActiveJob::DeserializationError'
     ].freeze
 
     # Note the order - we have to remove circular references and bad characters
@@ -176,11 +181,12 @@ module Raven
     ].freeze
 
     LOG_PREFIX = "** [Raven] ".freeze
+    MODULE_SEPARATOR = "::".freeze
 
     def initialize
       self.async = false
       self.context_lines = 3
-      self.current_environment = ENV['RAILS_ENV'] || ENV['RACK_ENV'] || 'default'
+      self.current_environment = current_environment_from_env
       self.encoding = 'gzip'
       self.environments = []
       self.exclude_loggers = []
@@ -190,17 +196,17 @@ module Raven
       self.open_timeout = 1
       self.processors = DEFAULT_PROCESSORS.dup
       self.project_root = detect_project_root
-      self.proxy = nil
       self.rails_activesupport_breadcrumbs = false
       self.rails_report_rescued_exceptions = true
       self.release = detect_release
+      self.sample_rate = 1.0
       self.sanitize_credit_cards = true
       self.sanitize_fields = []
       self.sanitize_fields_excluded = []
       self.sanitize_http_headers = []
       self.send_modules = true
-      self.server = ENV['SENTRY_DSN'] if ENV['SENTRY_DSN']
-      self.server_name = resolve_hostname
+      self.server = ENV['SENTRY_DSN']
+      self.server_name = server_name_from_env
       self.should_capture = false
       self.ssl_verification = true
       self.tags = {}
@@ -209,6 +215,7 @@ module Raven
     end
 
     def server=(value)
+      return if value.nil?
       uri = URI.parse(value)
       uri_path = uri.path.split('/')
 
@@ -273,7 +280,8 @@ module Raven
 
       valid? &&
         capture_in_current_environment? &&
-        capture_allowed_by_callback?(message_or_exc)
+        capture_allowed_by_callback?(message_or_exc) &&
+        sample_allowed?
     end
     # If we cannot capture, we cannot send.
     alias sending_allowed? capture_allowed?
@@ -288,14 +296,21 @@ module Raven
       Backtrace::Line.instance_variable_set(:@in_app_pattern, nil) # blow away cache
     end
 
-    def detect_release
-      detect_release_from_git ||
-        detect_release_from_capistrano ||
-        detect_release_from_heroku
-    rescue => ex
-      logger.error "Error detecting release: #{ex.message}"
+    def exception_class_allowed?(exc)
+      if exc.is_a?(Raven::Error)
+        # Try to prevent error reporting loops
+        logger.debug "Refusing to capture Raven error: #{exc.inspect}"
+        false
+      elsif excluded_exception?(exc)
+        logger.debug "User excluded error: #{exc.inspect}"
+        false
+      else
+        true
+      end
     end
 
+    private
+
     def detect_project_root
       if defined? Rails.root # we are in a Rails application
         Rails.root.to_s
@@ -304,7 +319,33 @@ module Raven
       end
     end
 
-    private
+    def detect_release
+      detect_release_from_git ||
+        detect_release_from_capistrano ||
+        detect_release_from_heroku
+    rescue => ex
+      logger.error "Error detecting release: #{ex.message}"
+    end
+
+    def excluded_exception?(exc)
+      excluded_exceptions.any? { |x| get_exception_class(x) === exc }
+    end
+
+    def get_exception_class(x)
+      x.is_a?(Module) ? x : qualified_const_get(x)
+    end
+
+    # In Ruby <2.0 const_get can't lookup "SomeModule::SomeClass" in one go
+    def qualified_const_get(x)
+      x = x.to_s
+      if !x.match(/::/)
+        Object.const_get(x)
+      else
+        x.split(MODULE_SEPARATOR).reject(&:empty?).inject(Object) { |a, e| a.const_get(e) }
+      end
+    rescue NameError # There's no way to safely ask if a constant exist for an unknown string
+      nil
+    end
 
     def detect_release_from_heroku
       return unless running_on_heroku?
@@ -334,7 +375,7 @@ module Raven
     end
 
     def detect_release_from_git
-      `git rev-parse --short HEAD`.strip if File.directory?(".git") rescue nil
+      Raven.sys_command("git rev-parse --short HEAD") if File.directory?(".git")
     end
 
     def capture_in_current_environment?
@@ -361,11 +402,33 @@ module Raven
       false
     end
 
+    def sample_allowed?
+      return true if sample_rate == 1.0
+      if Random::DEFAULT.rand >= sample_rate
+        @errors << "Excluded by random sample"
+        false
+      else
+        true
+      end
+    end
+
     # Try to resolve the hostname to an FQDN, but fall back to whatever
     # the load name is.
     def resolve_hostname
       Socket.gethostname ||
         Socket.gethostbyname(hostname).first rescue server_name
     end
+
+    def current_environment_from_env
+      ENV['SENTRY_CURRENT_ENV'] || ENV['RAILS_ENV'] || ENV['RACK_ENV'] || 'default'
+    end
+
+    def server_name_from_env
+      if running_on_heroku?
+        ENV['DYNO']
+      else
+        resolve_hostname
+      end
+    end
   end
 end
