@@ -1,9 +1,10 @@
 require 'spec_helper'
 
-describe Raven::Configuration do
+RSpec.describe Raven::Configuration do
   before do
     # Make sure we reset the env in case something leaks in
     ENV.delete('SENTRY_DSN')
+    ENV.delete('SENTRY_CURRENT_ENV')
     ENV.delete('RAILS_ENV')
     ENV.delete('RACK_ENV')
   end
@@ -77,6 +78,48 @@ describe Raven::Configuration do
     end
   end
 
+  context 'being initialized without a current environment' do
+    it 'defaults to "default"' do
+      expect(subject.current_environment).to eq('default')
+    end
+
+    it 'uses `SENTRY_CURRENT_ENV` env variable' do
+      ENV['SENTRY_CURRENT_ENV'] = 'set-with-sentry-current-env'
+      ENV['RAILS_ENV'] = 'set-with-rails-env'
+      ENV['RACK_ENV'] = 'set-with-rack-env'
+
+      expect(subject.current_environment).to eq('set-with-sentry-current-env')
+
+      ENV.delete('SENTRY_CURRENT_ENV')
+      ENV.delete('RAILS_ENV')
+      ENV.delete('RACK_ENV')
+    end
+
+    it 'uses `RAILS_ENV` env variable' do
+      ENV['SENTRY_CURRENT_ENV'] = nil
+      ENV['RAILS_ENV'] = 'set-with-rails-env'
+      ENV['RACK_ENV'] = 'set-with-rack-env'
+
+      expect(subject.current_environment).to eq('set-with-rails-env')
+
+      ENV.delete('SENTRY_CURRENT_ENV')
+      ENV.delete('RAILS_ENV')
+      ENV.delete('RACK_ENV')
+    end
+
+    it 'uses `RACK_ENV` env variable' do
+      ENV['SENTRY_CURRENT_ENV'] = nil
+      ENV['RAILS_ENV'] = nil
+      ENV['RACK_ENV'] = 'set-with-rack-env'
+
+      expect(subject.current_environment).to eq('set-with-rack-env')
+
+      ENV.delete('SENTRY_CURRENT_ENV')
+      ENV.delete('RAILS_ENV')
+      ENV.delete('RACK_ENV')
+    end
+  end
+
   context 'with a should_capture callback configured' do
     before(:each) do
       subject.should_capture = ->(exc_or_msg) { exc_or_msg != "dont send me" }
@@ -100,4 +143,22 @@ describe Raven::Configuration do
       expect(subject.errors).to eq(["No public_key specified", "No secret_key specified", "No project_id specified"])
     end
   end
+
+  context "with a sample rate" do
+    before(:each) do
+      subject.server = 'http://12345:67890@sentry.localdomain:3000/sentry/42'
+      subject.sample_rate = 0.75
+    end
+
+    it 'captured_allowed false when sampled' do
+      allow(Random::DEFAULT).to receive(:rand).and_return(0.76)
+      expect(subject.capture_allowed?).to eq(false)
+      expect(subject.errors).to eq(["Excluded by random sample"])
+    end
+
+    it 'captured_allowed true when not sampled' do
+      allow(Random::DEFAULT).to receive(:rand).and_return(0.74)
+      expect(subject.capture_allowed?).to eq(true)
+    end
+  end
 end
