@@ -1,7 +1,7 @@
 require 'spec_helper'
 require 'raven/integrations/rack'
 
-describe Raven::Event do
+RSpec.describe Raven::Event do
   before do
     Raven::Context.clear!
     Raven::BreadcrumbBuffer.clear!
@@ -10,7 +10,7 @@ describe Raven::Event do
   context 'a fully implemented event' do
     let(:hash) do
       Raven::Event.new(:message => 'test',
-                       :level => 'warning',
+                       :level => 'warn',
                        :logger => 'foo',
                        :tags => {
                          'foo' => 'bar'
@@ -28,7 +28,7 @@ describe Raven::Event do
     end
 
     it 'has level' do
-      expect(hash[:level]).to eq(30)
+      expect(hash[:level]).to eq(:warning)
     end
 
     it 'has logger' do
@@ -56,7 +56,7 @@ describe Raven::Event do
     end
 
     it 'has platform' do
-      expect(hash[:platform]).to eq('ruby')
+      expect(hash[:platform]).to eq(:ruby)
     end
 
     it 'has SDK' do
@@ -167,7 +167,7 @@ describe Raven::Event do
                                    :method => 'POST',
                                    :query_string => 'biz=baz',
                                    :url => 'http://localhost/lol',
-                                   :cookies => nil)
+                                   :cookies => {})
     end
 
     it "sets user context ip address correctly" do
@@ -405,7 +405,7 @@ describe Raven::Event do
       end
 
       it 'has level ERROR' do
-        expect(hash[:level]).to eq(40)
+        expect(hash[:level]).to eq(:error)
       end
 
       it 'accepts an options hash' do
@@ -445,9 +445,8 @@ describe Raven::Event do
         expect(hash[:message]).to eq("Exception: #{message}")
       end
 
-      # sentry uses python's logging values; 40 is the value of logging.ERROR
       it 'has level ERROR' do
-        expect(hash[:level]).to eq(40)
+        expect(hash[:level]).to eq(:error)
       end
 
       it 'uses the exception class name as the exception type' do
@@ -637,10 +636,6 @@ describe Raven::Event do
         end
       end
 
-      it "sets the culprit" do
-        expect(hash[:culprit]).to eq("/path/to/some/file in function_name at line 22")
-      end
-
       context 'when a path in the stack trace is on the load path' do
         before do
           $LOAD_PATH << '/some'
@@ -657,14 +652,6 @@ describe Raven::Event do
       end
     end
 
-    describe "#get_file_context" do
-      it "delegates to the linecache" do
-        expect(subject.linecache).to receive(:get_file_context)
-
-        subject.get_file_context("this", 2, 10)
-      end
-    end
-
     it 'accepts an options hash' do
       expect(Raven::Event.capture_exception(exception, :logger => 'logger').logger).to eq('logger')
     end
